@@ -1,4 +1,3 @@
-# coding=utf-8
 """Core fuzzfetch implementation"""
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this file,
@@ -72,7 +71,7 @@ class Fetcher:
             build: build identifier. acceptable identifiers are: TaskCluster
                    namespace, hg changeset, date, 'latest'
             flags: ('asan', 'debug', 'fuzzing', 'coverage', 'valgrind', 'tsan',
-                    'no_opt', 'fuzzilli'),
+                    'no_opt', 'fuzzilli', 'nyx'),
                    each a bool, not all combinations exist in TaskCluster
             platform: force platform if different than current system
             nearest: Search for nearest build, not exact
@@ -120,6 +119,7 @@ class Fetcher:
                     tsan,
                     no_opt,
                     fuzzilli,
+                    nyx,
                 ) = self._flags
                 if not debug:
                     debug = "-debug" in build or "-dbg" in build
@@ -137,9 +137,19 @@ class Fetcher:
                     no_opt = "-noopt" in build
                 if not fuzzilli:
                     fuzzilli = "-fuzzilli" in build
+                if not nyx:
+                    nyx = "-nyx" in build
 
                 self._flags = BuildFlags(
-                    asan, tsan, debug, fuzzing, coverage, valgrind, no_opt, fuzzilli
+                    asan,
+                    tsan,
+                    debug,
+                    fuzzing,
+                    coverage,
+                    valgrind,
+                    no_opt,
+                    fuzzilli,
+                    nyx,
                 )
 
                 # Validate flags
@@ -183,6 +193,11 @@ class Fetcher:
                         "'build' is not a fuzzilli build, but fuzzilli=True given "
                         f"(build={build})"
                     )
+                if self._flags.nyx and "-nyx" not in build:
+                    raise FetcherException(
+                        "'build' is not a Nyx build, but nyx=True given "
+                        f"(build={build})"
+                    )
 
             # Attempt to fetch the build.  If it fails and nearest is set, try and find
             # the nearest build that matches
@@ -570,9 +585,7 @@ class Fetcher:
                 self.extract_zip(f"{target}.tests.zip", path=path)
 
         # used by Pernosco to locate source ('\n' is expected)
-        (path / "taskcluster-build-task").write_bytes(
-            f"{self.task_id}\n".encode("utf-8")
-        )
+        (path / "taskcluster-build-task").write_bytes(f"{self.task_id}\n".encode())
 
         LOG.info("Extracted into %s", path)
 
@@ -751,6 +764,7 @@ class Fetcher:
             args.valgrind,
             args.no_opt,
             args.fuzzilli,
+            args.nyx,
         )
         obj = cls(
             args.branch,
